@@ -9,9 +9,12 @@ import numpy as np
 from abc import ABC
 from tqdm import tqdm
 from .pre_process import preprocess
-from pre_processing import CorpusHandler as ch
 from sklearn.feature_extraction.text import HashingVectorizer
 
+try:
+    from pre_processing import CorpusHandler as ch
+except Exception:
+    pass
 
 # logging.config.fileConfig(logger_path)
 # logger = logging.getLogger('template_logger')
