@@ -3,7 +3,6 @@ Natural Language Processing module
 """
 import re
 import spacy
-from spacy.lang import pt
 import nltk
 import multiprocessing
 from nltk.stem.snowball import SnowballStemmer
@@ -16,12 +15,12 @@ from textblob import TextBlob
 
 try:
     nltk.word_tokenize('some word')
-except:
+except Exception:
     nltk.download('punkt')
 
 try:
     nltk.corpus.stopwords.words('portuguese')
-except:
+except Exception:
     nltk.download('stopwords')
 finally:
     STOP_WORDS = set(nltk.corpus.stopwords.words('portuguese'))
@@ -99,7 +98,9 @@ class CorpusHandler:
         """
         local_part = r"[0-9a-zA-Z!#$%&'*+-/=?^_`{|}~.]+"
         domain = r"[a-zA-Z][a-zA-Z0-9-.]*[a-zA-Z]\.\w{2,4}"
-        document = re.sub(r"\s{}@{}".format(local_part, domain), ' EMAIL ', document)
+        document = re.sub(r"\s{}@{}".format(local_part, domain),
+                          ' EMAIL ',
+                          document)
         return document
 
     @staticmethod
@@ -116,7 +117,8 @@ class CorpusHandler:
 
         Example:
 
-        >>> CorpusHandler.clean_site("This is a http://example.com or http://192.168.0.255")
+        >>> CorpusHandler.clean_site("This is a http://example.com or \
+                                     http://192.168.0.255")
         "This is a SITE or SITE"
         """
         scheme = r"[a-zA-Z][a-zA-Z0-9+-.]*:?//?"
@@ -130,8 +132,13 @@ class CorpusHandler:
         resource = r"(/[a-zA-Z0-9-._~!$&'/*+,;=]*)?"
         query = r"(\?[a-zA-Z0-9-._~!$&'/*+,;=]*)?"
         fragment = r"(#[a-zA-Z0-9-._~!$&'/*+,;=]*)?"
-        document = re.sub(r"{}{}{}{}{}".format(scheme_host, port, resource,
-                                             query, fragment), ' SITE ', document)
+        document = re.sub(r"{}{}{}{}{}".format(scheme_host,
+                                               port,
+                                               resource,
+                                               query,
+                                               fragment),
+                          ' SITE ',
+                          document)
         return document
 
     @staticmethod
@@ -154,11 +161,15 @@ class CorpusHandler:
         # Law number: 00/YEAR or 00
         number_law = r'([0-9]+)((\s|\.)+\d+)?'
         matchs = [('LEI', 'lei'), ('ARTIGO', r'art\.|art\w*'),
-                  ('DECRETO', 'decreto'),]
+                  ('DECRETO', 'decreto'), ]
 
         for word, regex in matchs:
-            document = re.sub(r'{}\s*{}\s*{}'.format(regex, word_number, number_law),
-                            r'{}_\2'.format(word), document, flags=re.I)
+            document = re.sub(r'{}\s*{}\s*{}'.format(regex,
+                                                     word_number,
+                                                     number_law),
+                              r'{}_\2'.format(word),
+                              document,
+                              flags=re.I)
 
         return document
 
@@ -193,7 +204,8 @@ class CorpusHandler:
             :document: the document text to apply regex
 
         Returns:
-            :document: the same document without numbers and letters in same word
+            :document: the same document without numbers and
+            letters in same word
 
         Example:
 
@@ -203,7 +215,6 @@ class CorpusHandler:
         # Remove wor00 00wo 00wor00 wo00rd and keep WORD_000
         return re.sub(r'([A-Z]+_\d+)|[^ ]*\d+[^ ]*', r'\1', document)
 
-
     @staticmethod
     def clean_document(document, **kwargs):
         """
@@ -267,7 +278,7 @@ class CorpusHandler:
         "This is a    éxàmplê"
         """
         return re.sub(r'[^ ]*[^-_úíóõôéêãáàâa-zA-Z0-9ç ]+[^ ]*',
-                    ' ', document)
+                      ' ', document)
 
     def clean_special_chars(document, **kwargs):
         """
@@ -296,6 +307,7 @@ class CorpusHandler:
 
     nlp = spacy.load("pt_core_news_sm")
     nlp.max_length = 10000000
+
     @classmethod
     def lemmatize(cls, document, **kwargs):
         """
@@ -317,7 +329,7 @@ class CorpusHandler:
         doc = cls.nlp(document, disable=['parser', 'ner'])
 
         for token in doc:
-            #print(token)
+            # print(token)
             texts.append(token.lemma_)
 
         return texts
@@ -346,7 +358,8 @@ class CorpusHandler:
         return document
 
     @classmethod
-    def remove_stop_words(cls, document, stop_words=[], extra_stop_words=[], **kwargs):
+    def remove_stop_words(cls, document, stop_words=[],
+                          extra_stop_words=[], **kwargs):
         """
         Remove the stop words
 
@@ -360,11 +373,15 @@ class CorpusHandler:
 
         >>> CorpusHandler.remove_stop_words("Document to example method")
         "Document example method"
-        >>> CorpusHandler.remove_stop_words("Document to example method", stop_words=['to', 'example'])
+        >>> CorpusHandler.remove_stop_words("Document to example method",
+        >>>                                 stop_words=['to', 'example'])
         "Document method"
-        >>> CorpusHandler.remove_stop_words("Document to example method", extra_stop_words=['Document'] )
+        >>> CorpusHandler.remove_stop_words("Document to example method",
+        >>>                                 extra_stop_words=['Document'] )
         "example method"
-        >>> CorpusHandler.remove_stop_words("Document to example method", stop_words=['example'], extra_stop_words=['Document'])
+        >>> CorpusHandler.remove_stop_words("Document to example method",
+        >>>                                 stop_words=['example'],
+        >>>                                 extra_stop_words=['Document'])
         "to method"
         """
 
@@ -380,6 +397,7 @@ class CorpusHandler:
         return document
 
     stemmer = SnowballStemmer("portuguese")
+
     @classmethod
     def snowball_stemmer(cls, document, **kwargs):
         """
@@ -414,16 +432,17 @@ class CorpusHandler:
 
         Example:
 
-        >>> CorpusHandler.remove_named_entities('Meu nome é Roberto.', entities['per'])
+        >>> CorpusHandler.remove_named_entities('Meu nome é Roberto.',
+        >>>                                     entities['per'])
         "Meu nome é ."
         """
         blob = TextBlob(document)
         document = []
 
-        for sentence in blob.sentences:
-            tokens = nltk.word_tokenize(sentence.raw)
-            sentence = cls.nlp(sentence.raw)
-            fil = [str(x) for x in sentence.ents if x.label_.lower() in entities]
+        for stce in blob.sentences:
+            tokens = nltk.word_tokenize(stce.raw)
+            stce = cls.nlp(stce.raw)
+            fil = [str(x) for x in stce.ents if x.label_.lower() in entities]
             document.append(' '.join([x for x in tokens if x not in fil]))
 
         document = ' '.join(document)
@@ -431,8 +450,6 @@ class CorpusHandler:
         return document
 
 
-
-
 class BatchProcessing:
     """
     Execute a block of function in a corpus of text
@@ -446,7 +463,8 @@ class BatchProcessing:
         Receive a list of functions to apply in a document of text
 
         Arguments:
-            :functions: a list of functions to apply in document. It can be a str, function or dictionary
+            :functions: a list of functions to apply in document. It can be a
+             str, function or dictionary
             :document: a text to apply transformations
             :extra_kwargs: a dictionary with function name and the kwargs
 
@@ -455,31 +473,34 @@ class BatchProcessing:
 
         Example:
 
-        >>> BatchProcessing.batch_processing([str.lower], "EXEMPLIFY THE DOCUMENTS")
+        >>> BatchProcessing.batch_processing([str.lower],
+        >>>                                  "EXEMPLIFY THE DOCUMENTS")
         "exemplify the documents"
         >>> BatchProcessing.batch_processing([int], "12")
         12
         >>> BatchProcessing.batch_processing([{int: {'base': 2}}], "10")
         2
-        >>> BatchProcessing.batch_processing([int], "10", extra_kwargs={'int': {'base': 2}})
+        >>> BatchProcessing.batch_processing([int], "10",
+        >>>                                  extra_kwargs={'int': {'base': 2}})
         2
         """
         for function in functions:
-            kwargs={}
+            kwargs = {}
             # Extract the function or function name from dict item
             if isinstance(function, dict):
                 if len(function) == 1:
                     function, kwargs = tuple(function.items())[0]
                 else:
                     raise TypeError('Should be passed only a function per'
-                        'position to functions')
+                                    'position to functions')
             # Obtain a function from str value
             if isinstance(function, str):
                 if hasattr(cls.base_class, function):
                     function = getattr(cls.base_class, function)
                 else:
                     raise AttributeError('Function {}'.format(function) +
-                                         'not implemented in {}'.format(cls.base_class))
+                                         'not implemented in {}'.format(
+                                             cls.base_class))
             if function.__name__ in extra_kwargs:
                 kwargs.update(extra_kwargs[function.__name__])
             document = cls.call_function(function, document, **kwargs)
@@ -516,14 +537,16 @@ class BatchProcessing:
 
     @classmethod
     def parallel_processing(cls, functions, corpus=[], n_jobs=-1,
-            progress=False, extra_kwargs={}):
+                            progressi=False, extra_kwargs={}):
         """
         Apply a function in corpus using parallel lib
 
         Arguments:
-            :functions: a list of functions to apply in document. It can be a str, function or dictionary
+            :functions: a list of functions to apply in document.
+             It can be a str, function or dictionary
             :corpus: a array of texts to apply a function
-            :n_jobs: the number of parallel executions, if not pass, it will use all cores
+            :n_jobs: the number of parallel executions, if not pass,
+             it will use all cores
             :progress: show the status of processing, by default use tqdm
             :extra_kwargs: a dictionary with function name and the kwargs
 
@@ -532,32 +555,46 @@ class BatchProcessing:
 
         Example:
 
-        >>> BatchProcessing.parallel_processing([str.lower], ["EXEMPLIFY THE DOCUMENTS", "TO LOWER"])
+        >>> BatchProcessing.parallel_processing([str.lower],
+        >>>                                     ["EXEMPLIFY THE DOCUMENTS",
+        >>>                                     "TO LOWER"])
         ["exemplify the documents", "to lower"]
-        >>> BatchProcessing.parallel_processing([{int: {'base': 2}}], ["10", "100", "101"])
+        >>> BatchProcessing.parallel_processing([{int: {'base': 2}}],
+        >>>                                     ["10", "100", "101"])
         [2, 4, 5]
-        >>> BatchProcessing.parallel_processing([int], ["10", "100", "101"], extra_kwargs={'int': {'base': 2}})
+        >>> BatchProcessing.parallel_processing([int], ["10", "100", "101"],
+        >>>                                     extra_kwargs={'int':
+        >>>                                                         {'base': 2}
+        >>>                                                 })
         [2, 4, 5]
-        >>> BatchProcessing.parallel_processing([int], ["10", "100", "101", "110", "111"], extra_kwargs={'int': {'base': 2}}, progress=True)
-        100%|█████████████████████████████████████████████████| 5/5 [00:00<00:00, 84.99it/s]
+        >>> BatchProcessing.parallel_processing([int],
+        >>>                                     ["10",
+        >>>                                         "100",
+        >>>                                         "101",
+        >>>                                         "110",
+        >>>                                         "111"],
+        >>>                                     extra_kwargs={'int':
+        >>>                                                      {'base': 2}
+        >>>                                                  },
+        >>>                                     progress=True)
+        100%|█████████████████████████████████████████████████| 5/5
+                                                       [00:00<00:00, 84.99it/s]
         [2, 4, 5, 6, 7]
         """
         if n_jobs == -1:
             n_jobs = multiprocessing.cpu_count()
         parallel = range(0)
         # Conditional use of status
-        if progress:
+        if progressi:
             corpus_len = len(corpus)
             parallel = tqdm(
                             (delayed(cls.batch_processing)(functions, document,
-                                extra_kwargs)
-                            for document in corpus),
-                            total=corpus_len
-                    )
+                             extra_kwargs)
+                             for document in corpus), total=corpus_len)
         else:
             parallel = (delayed(cls.batch_processing)(functions, document,
-                extra_kwargs)
-                            for document in corpus)
+                        extra_kwargs)
+                        for document in corpus)
 
         data = Parallel(n_jobs=n_jobs)(parallel)
         return data
